@@ -62,7 +62,7 @@ class AnaDroid(object):
                  testing_framework=TESTING_FRAMEWORK.MONKEY, device=None, instrumenter=INSTRUMENTER.JINST,
                  analyzer=ANALYZER.OLD_ANADROID_ANALYZER, instrumentation_type=INSTRUMENTATION_TYPE.ANNOTATION,
                  build_system=BUILD_SYSTEM.GRADLE, build_type=BUILD_TYPE.DEBUG, tests_dir=None, rebuild_apps=False,
-                 reinstrument=False, recover_from_last_run=False, test_cmd=None):
+                 reinstrument=False, recover_from_last_run=False, test_cmd=None, load_projects=True):
         self.device = device if device is not None else get_first_connected_device()
         self.app_projects_ut = []
         self.tests_dir = tests_dir
@@ -75,7 +75,7 @@ class AnaDroid(object):
             self.__setup_from_argparse(arg1)
         else:
             self.apps_dir = os.path.realpath(arg1)
-            self.app_projects_ut = self.load_projects()
+            self.app_projects_ut = self.load_projects() if load_projects else []
         self.results_dir = results_dir
         self.test_cmd = test_cmd
         self.instrumentation_type = self.__infer_instrumentation_type(instrumentation_type)
@@ -393,7 +393,10 @@ class AnaDroid(object):
 
     def get_last_run_file(self):
         run_regex = r"\d+-\d+-\d+-\d+-\d+.*.log"
-        prev_logs = list(filter(lambda t: re.search(run_regex, t), mega_find(get_log_dir(), pattern='*.log', type_file='f', maxdepth=1)))
+        log_dir = get_log_dir()
+        if not os.path.exists(log_dir):
+            return None
+        prev_logs = list(filter(lambda t: re.search(run_regex, t), mega_find(log_dir, pattern='*.log', type_file='f', maxdepth=1)))
         if len(prev_logs) == 0:
             return None
         sorted_list = sorted(prev_logs, key=os.path.getmtime)
