@@ -14,7 +14,7 @@ class LogAnalyzer(AbstractAnalyzer):
     Calculate statistics about the produced logs to analyze and characterize test executions.
     """
     def __init__(self, profiler):
-        self.supported_filters = {"fatal_errors", "ANR"}
+        self.supported_filters = {"fatal_errors", "ANR", "Exceptions"}
         super(LogAnalyzer, self).__init__(profiler)
         self.logcatparser = LogCatParser(log_format="threadtime")
 
@@ -25,8 +25,8 @@ class LogAnalyzer(AbstractAnalyzer):
         #return os.path.join(app.curr_local_dir, f'test_{test_id}.logcat') TODO fetch test file name format from cfg file
         return [os.path.join(dir_path, f) for f in os.listdir(dir_path) if f'{test_id}.logcat' in f]
 
-    def analyze_tests(self, app, results_dir=None, **kwargs):
-        target_dir = app.curr_local_dir if results_dir is None else results_dir
+    def analyze_tests(self, app=None, results_dir=None, **kwargs):
+        target_dir = app.curr_local_dir if results_dir is None and app is not None else results_dir
         for log_file in self.fetch_log_files(target_dir):
             test_id = kwargs['test_id'] if 'test_id' in kwargs else os.path.basename(log_file).split("_")[1].split(".")[0]
             self.analyze_test(app, log_file, output_filename=f'test_{test_id}_logresume.json')
@@ -70,6 +70,8 @@ class LogAnalyzer(AbstractAnalyzer):
             return self.logcatparser.get_parser_resume()['stats']['fatal']
         elif filter_name == "ANR":
             return self.logcatparser.get_parser_resume()['known_errors']['ANR']
+        elif filter_name == "Exceptions":
+            return self.logcatparser.get_parser_resume()['known_errors']['Exception']
         val = super().get_val_for_filter(filter_name, add_data)
         if val is None:
             loge(f"unsupported value ({val}) for {filter_name} ({self.__class__})")
